# sforecast

A package to support supervised learning forecast methods (ML and DL) within a sliding forecast framework (sliding or expanding window)

## Installation

```bash
$ pip install sforecast
```

## License

`sforecast` was created by Alberto Gutierrez. It is licensed under the terms of the MIT license.

## Credits

`sforecast` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
